package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.40.1 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.40.1) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````0!P```````!``````````)@!`0``
M`````````$``.``*`$``&@`9``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```"4`@``````
M`)0"````````E`(````````;`````````!L``````````0`````````!````
M!0```````````````````````````````````-"9````````T)D`````````
M``$```````$````&````@/L```````"`^P$``````(#[`0``````"`4`````
M```P!0```````````0```````@````8```"0^P```````)#[`0``````D/L!
M```````0`@```````!`"````````"``````````$````!````'`"````````
M<`(```````!P`@```````"0`````````)``````````$``````````0````$
M````L)D```````"PF0```````+"9````````(``````````@``````````0`
M````````4.5T9`0`````D@````````"2`````````)(````````,`0``````
M``P!````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````@/L```````"`
M^P$``````(#[`0``````@`0```````"`!`````````$`````````!````!0`
M```#````1TY5`/P`X9$<$P5(D&ISF<#U:.;$=G-!+VQI8B]L9"UL:6YU>"UA
M87)C:#8T+G-O+C$```$````!`````0``````````````````````````````
M``````````````````````````````````````,`"@#X%0``````````````
M``````````,`%@````(`````````````````<0```!(`````````````````
M````````S0$``!(`````````````````````````>P```!(`````````````
M````````````>P$``!(`````````````````````````G`$``!(`````````
M````````````````/@(``!(`````````````````````````U`$``!(`````
M````````````````````AP```!(``````````````````````````0```"``
M````````````````````````'P(``!(`````````````````````````&`(`
M`!(`````````````````````````VP$``!(`````````````````````````
MN0```!(`````````````````````````_@(``!$`````````````````````
M````80```!(`````````````````````````M0(``!(`````````````````
M````````YP```!(`````````````````````````*`(``!(`````````````
M````````````EP$``!(`````````````````````````Q0$``!(`````````
M````````````````I`$``!(`````````````````````````@@(``"(`````
M````````````````````$````"``````````````````````````W````!(`
M````````````````````````+````"``````````````````````````M0$`
M`!(`````````````````````````V@(``!(`````````````````````````
M6P(``!(`````````````````````````K@(``!(`````````````````````
M````=`(``!$`````````````````````````U`(``!(`````````````````
M````````4P```!(`````````````````````````)P$``!8`````````````
M````````````!`$``!(`````````````````````````6P$``!(`````````
M````````````````ZP$``!(`````````````````````````J````!(`````
M````````````````````]0```!(`````````````````````````IP(``!(`
M````````````````````````PP(``!(`````````````````````````[`(`
M`!(`````````````````````````\0$``!(`````````````````````````
M3`(``!(`````````````````````````S0```!(`````````````````````
M````A@$``!(`````````````````````````"0(``!(`````````````````
M````````F@```!(`````````````````````````(`$``!(`````````````
M````````````3P$``!(`````````````````````````6@(``!(`````````
M````````````````O`(``!(`````````````````````````GP(``!(`````
M````````````````````]@$``!(`````````````````````````K@$``!(`
M````````````````````````.@$``!(`````````````````````````D0(`
M`!(`````````````````````````%`$``!(`````````````````````````
M`P(``!(`````````````````````````>P(``!(`````````````````````
M````1@```!$`````````````````````````=@```!(`````````````````
M````````P@```!(`````````````````````````;`$``!(`````````````
M````````````8@(``!(`````````````````````````X@(``!$`````````
M````````````````O@$``!(`````````````````````````Y`$``!(`````
M````````````````````,`(``!(`````````````````````````Y`(``!$`
M````````````````````````F`(``!(``````````````````````````%]?
M9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`%!,7V1O7W5N9'5M<`!097)L7W-Y<U]T
M97)M`%!E<FQ?9W9?9F5T8VAP=@!P97)L7V9R964`4&5R;%]G971?<W8`4&5R
M;%]A=&9O<FM?=6YL;V-K`'!E<FQ?9&5S=')U8W0`4&5R;%]N97=84U]F;&%G
M<P!P97)L7W)U;@!097)L7VYE=UA3`%!E<FQ?<W9?<V5T<'9N`'!E<FQ?86QL
M;V,`4&5R;%]S=E]S971P=@!P97)L7V-O;G-T<G5C=`!B;V]T7T1Y;F%,;V%D
M97(`4&5R;%]S869E<WES;6%L;&]C`%!,7V-U<G)E;G1?8V]N=&5X=`!097)L
M7V-R;V%K7VYO8V]N=&5X=`!097)L7VUG7W-E=`!097)L7V%T9F]R:U]L;V-K
M`%!E<FQ?<WES7VEN:70S`'!E<FQ?<&%R<V4`7U]S=&%C:U]C:&M?9F%I;`!E
M>&ET`&QS965K-C0`<F5A9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`
M<W1R<F-H<@!U;FQI;FL`<W1R=&]K`&=E='!W=6ED`'-T<FQE;@!R;61I<@!R
M96%D`%]?;65M8W!Y7V-H:P!M:V1I<@!?7W9F<')I;G1F7V-H:P!G971P:60`
M<F5A9&QI;FL`<F5A;&QO8P!?7W-P<FEN=&9?8VAK`%]?;65M;6]V95]C:&L`
M7U]F<')I;G1F7V-H:P!L<W1A=#8T`%]?;&EB8U]S=&%R=%]M86EN`'-T9&5R
M<@!M96UC:'(`7U]C>&%?9FEN86QI>F4`<W1R8VAR`&UE;7-E=`!O<&5N9&ER
M`&=E='5I9`!A8V-E<W,`;65M8W!Y`'-T<F-M<`!?7V5R<FYO7VQO8V%T:6]N
M`&%B;W)T`'-T<FYC;7``7U]E;G9I<F]N`%]?<F5G:7-T97)?871F;W)K`%]?
M<W1A8VM?8VAK7V=U87)D`&QI8G!E<FPN<V\N-2XT,`!L:6)C+G-O+C8`;&0M
M;&EN=7@M86%R8V@V-"YS;RXQ`$=,24)#7S(N,3<`1TQ)0D-?,BXS-`!'3$E"
M0U\R+C,S```````````!``(``0`!``(``@`"``$``0`"``(``@`!``,``0`"
M``$``@`"``(``@`"``$``0`!``(``@`$``(``@`"``$``0`!``$``@`!``$`
M`@`"``(``@`"``$``@`"``$``@`!``0``@`"``(``@`!``(``0`"``(``0`"
M``$``0`%``(``@`"``(``@`"```````!``$`*@,``!`````@````EY&6!@``
M`P!``P````````$``P`@`P``$`````````"TD98&```%`$L#```0````LY&6
M!@``!`!6`P``$````)>1E@8```(`0`,```````"`^P$```````,$````````
M8!T```````"(^P$```````,$````````#!T```````#X_P$```````,$````
M`````!H````````(``(```````,$````````"``"```````@``(```````,$
M````````0%0````````H``(```````,$````````T%`````````X``(`````
M``,$````````P%$```````!```(```````,$````````(%0```````!(``(`
M``````,$````````*%0```````!0``(```````,$````````,%0```````!8
M``(```````,$````````.%0```````!H``(```````,$````````"%0`````
M``!P``(```````,$````````$%0```````"```(```````,$````````2%0`
M``````"8_P$```````$$```*``````````````"@_P$```````$$```+````
M``````````"H_P$```````$$```0``````````````"P_P$```````$$```8
M``````````````"X_P$```````$$```9``````````````#`_P$```````$$
M```;``````````````#(_P$```````$$```@``````````````#0_P$`````
M``8$```C``````````````#8_P$```````$$```D``````````````#@_P$`
M``````$$```E``````````````#H_P$```````$$```^``````````````#P
M_P$```````$$``!'``````````````"X_0$```````($```#````````````
M``#`_0$```````($```$``````````````#(_0$```````($```%````````
M``````#0_0$```````($```&``````````````#8_0$```````($```'````
M``````````#@_0$```````($```(``````````````#H_0$```````($```)
M``````````````#P_0$```````($```+``````````````#X_0$```````($
M```,````````````````_@$```````($```-```````````````(_@$`````
M``($```.```````````````0_@$```````($```/```````````````8_@$`
M``````($```1```````````````@_@$```````($```2```````````````H
M_@$```````($```3```````````````P_@$```````($```4````````````
M```X_@$```````($```5``````````````!`_@$```````($```6````````
M``````!(_@$```````($```7``````````````!0_@$```````($```8````
M``````````!8_@$```````($```:``````````````!@_@$```````($```<
M``````````````!H_@$```````($```=``````````````!P_@$```````($
M```>``````````````!X_@$```````($```?``````````````"`_@$`````
M``($```A``````````````"(_@$```````($```B``````````````"0_@$`
M``````($```F``````````````"8_@$```````($```G``````````````"@
M_@$```````($```H``````````````"H_@$```````($```I````````````
M``"P_@$```````($```J``````````````"X_@$```````($```K````````
M``````#`_@$```````($```L``````````````#(_@$```````($```M````
M``````````#0_@$```````($```N``````````````#8_@$```````($```O
M``````````````#@_@$```````($```P``````````````#H_@$```````($
M```Q``````````````#P_@$```````($```R``````````````#X_@$`````
M``($```S````````````````_P$```````($```T```````````````(_P$`
M``````($```U```````````````0_P$```````($```V```````````````8
M_P$```````($```W```````````````@_P$```````($```X````````````
M```H_P$```````($```Y```````````````P_P$```````($```Z````````
M```````X_P$```````($```[``````````````!`_P$```````($```\````
M``````````!(_P$```````($```]``````````````!0_P$```````($```_
M``````````````!8_P$```````($``!```````````````!@_P$```````($
M``!!``````````````!H_P$```````($``!"``````````````!P_P$`````
M``($``!$``````````````!X_P$```````($``!%``````````````"`_P$`
M``````($``!&``````````````"(_P$```````($``!(```````````````?
M(`/5_7N_J?T#`)&<`0"4_7O!J,`#7];P>[^I\```T!':1OD0PC:1(`(?UA\@
M`]4?(`/5'R`#U?```-`1WD;Y$.(VD2`"'];P``#0$>)&^1`"-Y$@`A_6\```
MT!'F1OD0(C>1(`(?UO```-`1ZD;Y$$(WD2`"'];P``#0$>Y&^1!B-Y$@`A_6
M\```T!'R1OD0@C>1(`(?UO```-`1]D;Y$*(WD2`"'];P``#0$?I&^1#"-Y$@
M`A_6\```T!'^1OD0XC>1(`(?UO```-`1`D?Y$`(XD2`"'];P``#0$09'^1`B
M.)$@`A_6\```T!$*1_D00CB1(`(?UO```-`1#D?Y$&(XD2`"'];P``#0$1)'
M^1"".)$@`A_6\```T!$61_D0HCB1(`(?UO```-`1&D?Y$,(XD2`"'];P``#0
M$1Y'^1#B.)$@`A_6\```T!$B1_D0`CF1(`(?UO```-`1)D?Y$"(YD2`"'];P
M``#0$2I'^1!".9$@`A_6\```T!$N1_D08CF1(`(?UO```-`1,D?Y$((YD2`"
M'];P``#0$39'^1"B.9$@`A_6\```T!$Z1_D0PCF1(`(?UO```-`1/D?Y$.(Y
MD2`"'];P``#0$4)'^1`".I$@`A_6\```T!%&1_D0(CJ1(`(?UO```-`12D?Y
M$$(ZD2`"'];P``#0$4Y'^1!B.I$@`A_6\```T!%21_D0@CJ1(`(?UO```-`1
M5D?Y$*(ZD2`"'];P``#0$5I'^1#".I$@`A_6\```T!%>1_D0XCJ1(`(?UO``
M`-`18D?Y$`([D2`"'];P``#0$69'^1`B.Y$@`A_6\```T!%J1_D00CN1(`(?
MUO```-`1;D?Y$&([D2`"'];P``#0$7)'^1"".Y$@`A_6\```T!%V1_D0HCN1
M(`(?UO```-`1>D?Y$,([D2`"'];P``#0$7Y'^1#B.Y$@`A_6\```T!&"1_D0
M`CR1(`(?UO```-`1AD?Y$"(\D2`"'];P``#0$8I'^1!"/)$@`A_6\```T!&.
M1_D08CR1(`(?UO```-`1DD?Y$((\D2`"'];P``#0$99'^1"B/)$@`A_6\```
MT!&:1_D0PCR1(`(?UO```-`1GD?Y$.(\D2`"'];P``#0$:)'^1`"/9$@`A_6
M\```T!&F1_D0(CV1(`(?UO```-`1JD?Y$$(]D2`"'];P``#0$:Y'^1!B/9$@
M`A_6\```T!&R1_D0@CV1(`(?UO```-`1MD?Y$*(]D2`"'];P``#0$;I'^1#"
M/9$@`A_6\```T!&^1_D0XCV1(`(?UO```-`1PD?Y$`(^D2`"'];P``#0$<9'
M^1`B/I$@`A_6```````````````````````````````````````````_(P/5
M_X,!T?U[`ZG]PP"1X!\`N>```-``U$?YXH<`J>(C`)'S4P2I]5L%J0$`0/GA
M%P#Y`0"`TN!S`)'A0P"1T/__E^(``-!"S$?YX```T`#P1_GA`P*J>@T`E.``
M`-``]$?Y``!`.4`)`#;@``#0`.A'^4'0.]7S``#P(6A@^"!H4CD`!``R(&@2
M.>`?0+D4#``1`!``$0!\?9.E__^7Y@M`^>,#`*I@0@*1P0!`^0,$`/D@``"0
M`.`/D6$``*G@``#P`4!`^2```)```!"180`!J>`?0+D?!`!Q#0D`5"$`@-(D
M#``1Q7AA^"$$`)%EV"3X'P`!:VS__U0`#``1=4("D7_8(/@!``"PX@,4*B&0
M#Y$$`(#2H`Y`^='^_Y<`!0`T=$("D8`.0/E9__^7]@,`*N&3`)$@``"0`$`%
MD9```)1`!`"T<T("D6`.0/FX_O^7'___E^```-``U$?YXA=`^0$`0/E"``'K
M`0"`TN$$`%3]>T.IX`,6*O-31*GU6T6I_X,!D;\C`]7``U_6^/[_E_,``/!B
M0@*10`P`^2`#`+07__^7X```T`#H1_E!T#O5(FA@^%]8)#FP__\7H`Y`^<?^
M_Y?7__\7@`I`^6```+3$!P"4W/__%^&3`)$@``"0`&`#D68``)2`"@#YP/K_
MM+P'`)34__\7@`"`4L#__Q<@`(!2RO[_EQG__Y<?(`/5'R`#U1\@`]4?(`/5
M'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]4?(`/5'0"`TAX`@-+E
M`P"JX0-`^>(C`)'F`P"1X```T`#\1_D#`(#2!`"`TDG__Y?4_O^7X```T`#0
M1_E```"TB/[_%\`#7]8?(`/5'R`#U1\@`]4?(`/5'R`#U1\@`]7@``#P`"`"
MD>$``/`A(`*1/P``Z\```%3A``#0(=Q'^6$``+3P`P&J``(?UL`#7];@``#P
M`"`"D>$``/`A(`*1(0``RR+\?]-!#(&+(?Q!D\$``+3B``#00N!'^6(``+3P
M`P*J``(?UL`#7]8_(P/5_7N^J?T#`)'S"P#Y\P``\&`B0CE``0`WX```T`#8
M1_F```"TX```\``$0/F)_O^7V/__ER``@%)@(@(Y\PM`^?U[PJB_(P/5P`-?
MUA\@`]5?)`/5V___%Q\@`]4?(`/5'R`#U1\@`]4?(`/5'R`#U3\C`]7]>[RI
M_0,`D?=C`ZGX`P&JX0``T"'X1_GS4P&I-P!`^7<&`+3U6P*I%0"`4@$`0#D_
M]`!Q)!A`>D$#`%3S`D#Y,P(`M/8#`*JU?D"3]`,7JA\@`]4?(`/5'R`#U>(#
M%:KA`Q:JX`,3JFG^_Y>````U8&IU.!_T`'$@`@!4DXY`^//^_[7U6T*IX`,3
MJO-30:GW8T.I_7O$J+\C`]7``U_6]0,`JJ$>0#@_]`!Q)!A`>J'__U2U`@!+
MX?__%X`"%\NU!@"1<P(5BP#\0Y,``P"YX`,3JO5;0JGS4T&I]V-#J?U[Q*B_
M(P/5P`-?UA,`@-+F__\7'R`#U1\@`]4_(P/5_\,"T>$``-`AU$?Y_7L)J?U#
M`I'S4P#Y\P,`JB(`0/GB1P#Y`@"`TN$C`)&$_O^78`(`->$;0+D"`)12(0P4
M$C\00'$D$$)ZX`$`5.$``-`AU$?YXT=`^2(`0/EC``+K`@"`TL$!`%3S4T#Y
M_7M)J?_#`I&_(P/5P`-?U@``@%+S__\7X`,3JD$`@%(H_O^7'P``<>`7GQKM
M__\75/[_ES\C`]7_0P/1X0``T"'41_G]>PJI_8,"D2(`0/GB3P#Y`@"`TL``
M`+3S4PNI\P,`J@$`0#FA`0`U\U-+J>```-``U$?YXD]`^0$`0/E"``'K`0"`
MTD$)`%3]>TJI_T,#D;\C`]7``U_6]5L,J53^_Y?U`P"JP`8`M.`#%:KL_?^7
MX`4`M`%,0#D43`"1/[@`<6$``%2!!D`Y`?__-`!,0#D?N`!QH`4`5.`#$ZIX
M_O^7]@,`JN`#%*IU_O^7P@(`"T((`!%"?$"3X@<`^>`#`JHK_O^7]@,`JN('
M0/GE`Q2JY`,3J@,``/!CH`&100"`4FO^_Y?A8P"1X`,6JN#]_Y<?!``QH```
M5.`K0+D`#!02'Q!`<>`"`%3@`Q:J@/W_E^`#%JI&_O^7X`,5JL#]_Y>@^O^U
M'R`#U1\@`]7@`Q6JQ_W_E^`#$ZK=_?^7\U-+J?5;3*FZ__\7@`9`.1^X`'%!
M^O]4@`I`.8#X_S3/__\7X`,6JJ/__Y?J__\7\U,+J?5;#*GR_?^7/R,#U?^#
M`=']>P*I_8,`D?-3`ZGS`P"JX```L`#41_GU6P2I]V,%J0(`0/GB#P#Y`@"`
MTB``0#D?]`!Q-!2!FN`#%*HP_O^7]0,`JN%3`)'@`Q.J(/__EX`(`+3V`P"J
M*?[_E[\"`.LI!P!4]A>`N?<``+#W^D?YUO)]TV`"0#D?]`!Q!!A`>J`,`%3C
M`Q.J'R`#U6`<0#@?]`!Q!!A`>J'__U1C`!/+8WQ`D_@"0/F@"@"1```#B\_]
M_Y<`:S;XH`(`M.`"0/D#:';X8`)`.6```#D?]`!Q!!A`>N```%1@!@"1`A1`
M.&(<`#A?]`!Q1!A`>H'__U2@!X!28!0`.```@-*":F`X8F@@.``$`)&B__\U
MX```L`#41_GB#T#Y`0!`^4(``>L!`(#2(0@`5/U[0JGS4T.I]5M$J?=C1:G_
M@P&1OR,#U<`#7]8!`(#2'R`#U8)J83C":B$X(00`D:+__S7L__\7]P``L/?Z
M1_GX`D#Y``-`^6`%`+3@`QBJ!`"`4@&,0/CB`P0JA`0`$:'__[5!#``1(7Q]
MD^```-#D!P"Y`I!`N:("`#4B`(!2`I``N>`#`:KA!P#YCOW_EZ#Z_[3C!T#Y
MX0,8JN0'0+GD!P"YX`<`^99\?9/B`Q:J_?S_E^0'0+GE!T#YY0(`^80$`!&_
MV"3XH?__%^`#&*H=_?^7X`(`^>4#`*I`^/^TY`=`N99\?9/V__\7`P"`TJ/_
M_Q<!`H#2!`"`4MS__Q=E_?^7/R,#U?U[O:D-!(+2_0,`D?-3`:GU$P#Y_V,M
MR_\#`OGT`P"JX```L`#41_GU`P&J\V,`D>+_@=(!`$#YX0\(^0$`@-(```#P
MX0,3J@#``9'@_/^7'P``<<T``%0"?$"3``0`46'*8#@!`P`UP`(`->```+``
MZ$?Y0]`[U>(#%:KA`Q2J8&A@^.K\_Y?@``"P`-1'^>(/2/D!`$#Y0@`!ZP$`
M@-+A`@!4#02"TO]C+8OU$T#Y\U-!J?U[PZB_(P/5P`-?U@)\0)/@`Q.JX06`
M4N('`/EG_?^7P/S_M.```+``Z$?Y1-`[U>,'0/GB`Q.JX0,4JH!H8/@B_?^7
MY/__%R3]_Y<_(P/5_7N^J2,``/`!``#P_0,`D6/@!I'S4P&I5-`[U?,``+!S
MZD?YX@``L$+L1_DA``*1@&IS^%7]_Y>`:G/X!```\/-30:F$P`^1_7O"J+\C
M`]7C`P2J!0"`4@(``+`!``#P0@`CD2&``I'H_/\7'R`#U1\@`]4?(`/57R0#
MU>```+``Z$?Y1-`[U>(``+!"[$?Y(P``\`$``/!CX`:1@&A@^"$``I$Y_?\7
M/R,#U?U[O:D-!H32_0,`D?-3`:G_8RW+_P,"^>```+``U$?Y%`"`T@$`0/GA
M%Q#Y`0"`TG_\_Y?D`P`J(@""TD$`@%+@8P"1!0``\`,``/"EX`*18P`#D3;]
M_Y<#!(+2X&,`D>%C(XL"`(+2;?S_EP`"^#<#!``1\P,`JF-\0)/C!P#YX`,#
MJN+\_Y?T`P"J``$`M.,'0/ES?D"3X@,3J@$$@M+A8R&+[OS_EY]J,SC@``"P
M`-1'^>(74/D!`$#Y0@`!ZP$`@-(!`0!4#0:$TO]C+8O@`Q2J\U-!J?U[PZB_
M(P/5P`-?UO4K$/F]_/^77R0#U</__Q<_(P/5_7N[J0T2@M+]`P"1\U,!J?5;
M`JG_8RW+_P,"^?4#`*K@``"P`-1'^?,#`:H!`$#YX4<(^0$`@-(```#PX1,`
MD0!@`Y'L_?^7]`,`JN$%@%+@`Q6JT/S_EX`"`+3A`Q6J````\`"@`Y&N_O^7
MX`,5JN$``+`AU$?YXT=(^2(`0/EC``+K`@"`TB$-`%0-$H+2_V,MB_-30:GU
M6T*I_7O%J+\C`]7``U_6X`,3JK+\_Y<6``#PP>(#D1/\_Y?S`P"JX/S_M/AG
M"/D8``#P&",$D?EK"/D9``#P.0,$D?=C"/GZ;PCY8`)`.>`&`#2T``"TX0,3
MJN`#%*J3_/^7``4`-.`#$ZK(_/^7`@0`T?H#`*IB`@*+?P("ZZ,``%0*```4
M7_0?.'\"`NN```!40`!`.1^\`'%@__]4X`,3JKK\_Y?Z`P"JX`,5JK?\_Y<`
M`!J+``0`D1_\/_'(`@!4Y@,5JN4#&:KD`Q.JXP,8J@(`@M)!`(!2X","D:_\
M_Y?A(P"1X","D23\_Y>@```UX!M`N0`,%!(?($!QP`(`5,'B`Y$``(#2V/O_
ME_,#`*K`^?^U]V-(^?AG2/GY:TCY^F](^:?__Q>4``"T@`)`.1^X`'&@``!4
M$P``\#H`@-)S0@.1V?__%X`&0#F@_?\T^O__%^`C`I$A`(!2"_S_EP#]_S7A
M(P*1````\`"@`Y%%_O^7X","D5C\_Y?W8TCY^&=(^?EK2/GZ;TCYDO__%_=C
M"/GX9PCY^6L(^?IO"/DJ_/^7/R,#U?U[OJGA!8!2_0,`D?,+`/GS`P"JU_O_
MEQ\``/%@!H":\PM`^?U[PJB_(P/50?S_%S\C`]7]>[ZI#02"TOT#`)'_8RW+
M_P,"^>$``+`AU$?Y(@!`^>(/"/D"`(#2@`8`M/,;"/GT'PCY]`,`J@$`0#FA
M!0`T6_S_EP($`)'C`P"J7P1`\4@'`%3S8P"1X0,4JN`#$ZKC!P#YIOO_E^,'
M0/E@!`#18`(`BQ\`$^NH``!4!P``%!_T'S@?`!/K@```5`$`0#D_O`!Q8/__
M5.`#$ZKA!8!2I_O_E^`$`+0?`!/K*`0`5.`#$ZH2_/^7X0``L"'41_GC#TCY
M(@!`^6,``NL"`(#2`04`5/,;2/D-!(+2]!](^?]C+8O]>\*HOR,#U<`#7];S
M&TCY]!](^>```+``U$?YX@](^0$`0/E"``'K`0"`TB$#`%0```#P`$`#D0T$
M@M+_8RV+_7O"J+\C`]7T^_\7'P``.=___Q<``(#2W___%^```+``U$?YX@](
M^0$`0/E"``'K`0"`TL$``%3S&TCY````\/0?2/D`0`.1[/__%[_[_Y?S&PCY
M]!\(^;S[_Y<_(P/5_X,!T>```+``U$?Y_7L!J?U#`)'S4P*I%```\)1"!)'U
M6P.I]V,$J?DK`/GU``"PM?I'^0$`0/GA!P#Y`0"`TN$3`)'@`Q2J[/S_E^`!
M`+2B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0!"$#Y`00`^0`@`)&A__^UX1,`
MD>`#%*K>_/^78/[_M?4``+"U^D?Y%```\)2"!)'A$P"1X`,4JM;\_Y?@`0"T
MH@)`^>,'@+E`#`.+`01`^4%X(_CA_O^T`0A`^0$$`/D`(`"1H?__M>$3`)'@
M`Q2JR/S_EV#^_[7U``"PM?I'^10``/"4H@21X1,`D>`#%*K`_/^7X`$`M*("
M0/GC!X"Y0`P#BP$$0/E!>"/XX?[_M`$(0/D!!`#Y`"``D:'__[7A$P"1X`,4
MJK+\_Y=@_O^U]0``L+7Z1_D4``#PE.($D>$3`)'@`Q2JJOS_ER`"`+2B`D#Y
MXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A
M$P"1X`,4JIK\_Y<@_O^U]@``L-;Z1_D4``#PE0(%D>$3`)'@`Q6JDOS_ER`"
M`+3"`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``
MD:'__[7A$P"1X`,5JH+\_Y<@_O^U]@``L-;Z1_D5``#PM4(%D>$3`)'@`Q6J
M>OS_ER`"`+3"`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!
M!`#Y`"``D:'__[7A$P"1X`,5JFK\_Y<@_O^U]P``L/?Z1_D5``#PMF(#D>$3
M`)'@`Q:J8OS_ER`"`+3B`D#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#
MU0$(0/D!!`#Y`"``D:'__[7A$P"1X`,6JE+\_Y<@_O^U^```L!C[1_D6``#P
MUX(%D>$3`)'@`Q>J2OS_ER`"`+0"`T#YXP>`N4`,`XL!!$#Y07@C^.'^_[0?
M(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A$P"1X`,7JCK\_Y<@_O^U^0``L#G[
M1_D7``#P^,(%D>$3`)'@`QBJ,OS_ER`"`+0B`T#YXP>`N4`,`XL!!$#Y07@C
M^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A$P"1X`,8JB+\_Y<@_O^U
M^0``L#G[1_D8``#P&`,&D>$3`)'@`QBJ&OS_ER`"`+0B`T#YXP>`N4`,`XL!
M!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A$P"1X`,8J@K\
M_Y<@_O^U^0``L#G[1_D8``#P&*,#D>$3`)'@`QBJ`OS_ER`"`+0B`T#YXP>`
MN4`,`XL!!$#Y07@C^.'^_[0?(`/5'R`#U0$(0/D!!`#Y`"``D:'__[7A$P"1
MX`,8JO+[_Y<@_O^U````\.$3`)$`0`:1[?O_EX```+3A`P"JX,(%D;3\_Y<`
M``#PX1,`D0"@!I'E^_^7H```M.$#`*H```#P```'D:O\_Y<```#PX1,`D0!`
M!Y'<^_^7P`(`M.$#`*J@8@.1H_S_E^```+``U$?YX@=`^0$`0/E"``'K`0"`
MTJ$"`%3]>T&I@`(%D?5;0ZD!``#P\U-"J2'@!Y'W8T2I^2M`^?^#`9&_(P/5
MD?S_%P```/#A$P"1`(`'D<+[_Y=`_?^TX0,`JL""!9&)_/^7YO__%WCZ_Y<?
M(`/5'R`#U1\@`]4_(P/5_X,`T>```+``U$?Y_7L!J?U#`)$!`$#YX0<`^0$`
M@-(```#PX1,`D0"`!9&L^_^7``(`M```0#D?P`!Q!!A`>N`'GQKA``"P(=1'
M^>,'0/DB`$#Y8P`"ZP(`@-+A``!4_7M!J?^#`)&_(P/5P`-?U@``@%+T__\7
M5?K_ES\C`]7_`P71_7L'J?W#`9'ABQ"IX0``L"'41_GCDQ&IXP,`D>6;$JGG
MGP#YX`<$K>(/!:WD%P:MYA\'K2(`0/GB-P#Y`@"`TN$#!9'AAP*IX0,$D>(#
M`*KA'P#YX0:`$N%#`+GA#X`2X4<`N4$`@%+^@\(\_X/#/.```+``Y$?Y_@.`
M/?\'@#T``$#Y_H.$//^#A3PS^O^7X!^`4MWY_Y<_(P/5_7N]J?T#`)'S4P&I
M]5L"J?]#0-'_`P+Y_T,`T?\#`OGB0T"1X0``L"'41_GV`P`J(P!`^4,$`/D#
M`(#2`0"`TD(`@%*:^?^7%00`T>`#%>NA/D"2`#Q`DB!$@-JU`@#K1`8`5/,#
M`)'T``"PX0,5JN`#%BH"`(!2C?G_EQ\$`+'@!0!4`@&`TN$#$ZK@`Q8J(@"@
M\OKY_Y<?!``QH`0`5`!\0),?'`#QJ0,`5``@`-%@`@"KHP``5!D``!0`!`#1
M'P`3Z\,"`%0!`$#Y@@I`^5\``>M!__]4```3RP``%8OA``"0(=1'^>-#0)%D
M!$#Y(@!`^80``NL"`(#280(`5/]#`)'_0T"1\U-!J?5;0JG]>\.HOR,#U<`#
M7]:U0D#1OT)`L4'Z_U0``("2[?__%P```-``0`B1B?__EP```-````B1AO__
ME]GY_Y<_(P/5_7N_J?T#`)&]^?^7;/G_ET```+0``$#Y_7O!J+\C`]7``U_6
M'R`#U1\@`]4_(P/5_T,!T?U[`JG]@P"1]5L$J?4#`*K@``"0`-1'^?-3`ZD3
M``#0`0!`^>$/`/D!`(#2=(((D>%3`)'@`Q2J`/O_EX```+3F`P"J``!`.0`"
M`#7@``"0`-1'^>(/0/D!`$#Y0@`!ZP$`@-)A!0!4_7M"J>$#%:I@@@B1]5M$
MJ?-30ZG_0P&1OR,#U;C[_Q?@`Q6JY@<`^?;Y_Y?S`P"JX`=`^?/Y_Y=S`@"+
M8`H`D:SY_Y?F!T#Y8@H`D4$`@%+V`P"JY`,5J@4``-`#``#0I>`#D6,@!)'J
M^?^7X```D`#41_GB#T#Y`0!`^4(``>L!`(#2(0$`5/U[0JGA`Q:JX`,4JO5;
M1*GS4T.I_T,!D;\C`]66^_\7AOG_EQ\@`]4_(P/5_X,&T?U[%*G]`P61]V,7
MJ?<#`*K@``"0`-1'^?-3%:GS@P"1]5L6J?7C`)'T<P"1`0!`^>&?`/D!`(#2
MX```L`!``)$6``#0`@Q!J>(/`JD"C$6IXH\#J1V`PCP>@,,\'X#$/`$00/EA
M"@#Y`#1`^:`*`/GA`Q2JP&(#D?W[`JW_'X`]IOK_EX```+0!`$`Y^`,`JH$B
M`#7Y:QBI^W,9J4/Y_Y?R^/^7P!``M!L`0/F;$`"TX`,;JJ7Y_Y<9^'_3.0<`
MD>`#&:I=^?^79`-`.?H#`*K\`QFJ^`,`JH0"`#05``#0M>((D>(#&:K@`QJJ
M00"`4N,#%:J9^?^76@L`D9\#&>MD'T`X@B.9FD$`&<LY"P#1(0@`D3\``NLA
M((*:(0`"RSD`&8L$_O\U````T/EC`9$```>1`P``%""'0/C@`0"TX0,4JG7Z
M_Y?U`P"J8/__M`$`0#DA__\TL/K_E^#^_S3@`Q6J3?G_E_4#`*J@`0"U'R`#
MU1\@`]5U`D#Y-0$`M*`"0#F@"P`TX`,5JJ/Z_Y>`"@`U<R(`D74"0/DU__^U
MX`,5JFGY_Y?Y`P"JX`,8JF;Y_Y<Y`P`+.1,0$1L``-`Y?T"3X`,9JASY_Y?G
M`QBJ90,$D>0#%:KB`QFJ!@``T`,``-#&``F18R`)D?H#`*I!`(!26?G_E^`#
M&JH!.(!2-OG_EQ\$`#&A``!4Z_C_EP4`0+F_1`!Q`14`5.$#`I'@`QJJ#?G_
ME_,#`"J@```UX)-`N0`,%!(?$$!QH`8`5.```)``Y$?Y`@``T.,"0/GD`QJJ
M``!`^4)@"I%!`(!2XOC_EQ4`@-+@``"0`-1'^>*?0/D!`$#Y0@`!ZP$`@-)!
M'@!4_7M4J>`#%:KY:UBI^W-9J?-35:GU6U:I]V-7J?^#!I&_(P/5P`-?UOOX
M_Y?[`P"J8`(`M;4B`)&@`D#Y`!,`M.$#%*H4^O^78/__M`$`0#G!_O\UM2(`
MD?C__Q?@`Q6J[?C_E_4#`*J@]?^U<R(`D:G__Q<5`(#2J?__%Q+Y_Y<9^'_3
M.0<`D6W__Q?UFT"YI?C_E[\"`&LA^?]4X)-`N0`@`!(?``=QH?C_5.`#&:K!
M^/^7X0,4JO4#`*H```#0`,`+D?3Y_Y?@#P"TX0,`JN`"0/GR^_^7^`,`JD`/
M`+3@`QBJ^/C_E_P#`*H?#`!Q+0(`5`!\0),!``#0`!``T2'@"Y$``P"+M_C_
MET`!`#6?$P!Q8!,`5)P7`%$`RWPX'[P`<>`2`%0?(`/5'R`#U1\@`]47``#0
MX0,4JN""!9'5^?^7H```M```0#D?P`!Q!!A`>L$``%3@`QBJ`0"`4M7X_Y?T
M`P`J(`L`->""!9$!``#0(>`'D9+Z_Y=[`P21%```T)3"#Y$8``#0$OC_EQCC
M#)'F`P`JYP,4JN4#&ZKD`QJJX@,9JN`#%:H#``#000"`4F.@#)''^/^7$0``
M%%WX_Y<``$"Y'T0`<4$"`%0!^/^7]`,`^7,&`!'F`P`JYP,3*N4#&ZKD`QJJ
MXP,8JN(#&:K@`Q6J00"`4K;X_Y?@`Q6J`3B`4I/X_Y<?!``Q@/W_5.`#&JJ7
M^/^7X0,5JL!B`Y%G^O^7X`,5JHK^_Y=M__\7X```D`#D1_GD`QJJXP)`^0(`
M`-```$#Y0F`)D4$`@%)$^/^78O__%W[^_Y?@``"0`-1'^>*?0/D!`$#Y0@`!
MZP$`@-*!"@!4_7M4J>`#&*KS4U6I]5M6J?=C5ZG_@P:1OR,#U5_X_Q>@`8#2
M1?C_E[P!@-(;``#0^@,`JO@#`*KY`QRJ>\,(D60*@%+F_O\7^`)`^8;__Q<"
M_O^7^`,`JL#T_[<!*`#1`@"`4N`#%"JH]_^7X0,$D>`#%"K"`(#2&/C_EQ\8
M`/'A!0!4X0-!N0!@B%(@:*AR/P``:^'R_U3A"T)Y`*F(4C\``&MA\O]4`<L`
MT0(`@%+@`Q0JE??_E^$C!)'@`Q0J`@6`T@7X_Y<?H`#Q@0,`5.8C!)%E`P21
MY`,:JN(#&:K@`Q6J!P``T`,``-#GP`^18V`,D4$`@%+_PP0Y5_C_EZ;__Q?W
M!D#YE^W_M.`#%ZI.^/^7'PP`\0GM_U0`$`#1`0``T.`"`(LA``R1#_C_EQ\`
M`'$8$Y>:8/__%P```-``(`R1G?W_E_#W_Y?Y:QBI^W,9J>WW_Y<_(P/5_T,!
MT>```)``U$?Y_7L!J?U#`)'S4P*I5-`[U?,``)!SZD?Y]5L#J?<C`/F5:G/X
M`0!`^>$'`/D!`(#2X1,`D:#"0CF@Q@(Y````T```!9$;^?^7@```M`$`0#D_
MQ`!Q8`L`5!?\_Y>5:G/XX`,5JF,`@%(B`(!2`0``T"%`#9%K]_^7]0,`JF`!
M`+0`"$#Y`@``T$)@#9$!`$#Y@&IS^&OW_Y>@"D#Y`0!`^2`,0+D`"K`W@&IS
M^&,`@%(B`(!2`0``T/<``+`A@`V16/?_E_4#`*J``0"TX1,`D0```-``H`.1
M]OC_EZ$*0/DC`$#Y0`<`M.(#`*KA`P.J@&IS^%/W_Y>5:G/X(@"`4@$``-`A
MH`V1X`,5JAWW_Y<"``#0X0,`JD(`#I'@`Q6J2/?_EX!J<_CT0@*1X1,`D1_$
M`CD```#0`&`#D=WX_Y>`"@#Y\P,`JL`"`+0!.(!2X`,3JL?W_Y<!!``1/P0`
M<02(47J!!`!4X```D`#41_GB!T#Y`0!`^4(``>L!`(#2@0,`5/<C0/G]>T&I
M\U-"J?5;0ZG_0P&1OR,#U<`#7]:`!D#Y^_W_EX`*`/GS`P"JX/S_M0```-``
M(`Z1H??_EP`$0#G@]/\TI/__%^!"`I$`!$#Y`0!`^>`#`ZH-^O^7QO__%X!J
M<_A^]_^7K___%VSW_Y?W0@*1XP,`*N(#$ZH```#0`,`.D>$&0/DA`$#YC/?_
MES\C`]7_PP#1_7L!J?U#`)'S4P*I\P,`JN```)``U$?Y`0!`^>$'`/D!`(#2
M````T.$3`)$`@`61F?C_ER`!`+0``$`Y'\``<0080'K@!Y\:?P(`\>$'GQH_
M``!JH0$`5.```)``U$?YX@=`^0$`0/E"``'K`0"`TD$$`%3]>T&I\U-"J?_#
M`)&_(P/5P`-?UF`"0#E@_O\TX`,3JB#[_Y?A!8!2]`,`JNWV_Y<?``#Q@`:`
MFEKW_Y<!``#0@@"`TB$`"9'Z]O^7P/S_->```)``U$?YX@=`^0$`0/E"``'K
M`0"`TN$``%3]>T&IX`,3JO-30JG_PP"1OR,#U='X_Q<C]_^7'R`#U1\@`]4?
M(`/5'R`#U1\@`]4?(`/5X0``D"'41_D_(P/5_7N_J0/@`9$7!`!/_0,`D?CE
M`&__0PK1F>0`;R(`0/GB1P'Y`@"`TESD`&\!X`"1X@,`D3Y\0&T]!,$\WCN?
M#K\'8&_>"R`NVCN73OY76$__5TA/WA\X3O\?.4[>'[].OP=8;[T'2&__'SQ.
M_Q^]3ML?OTY:C)],?P`!Z\']_U3Y'\`]X:,!D?CE`&_BHPF1__M`K?WS0:W[
MZT*M(4``D2"`V#PA`-\\]1\\;M\?ODX@'"!NOA^]3IT?O$Y\'[M.%1PU;EL?
MNDXZ'[E.M@9A;[6&]4[5'K5.N1XX3CF`@#Q?``'KP?W_5`0@0*D%&$&IXBM`
MJ8G\6],#_4+3*14$JF-X"*K!``7*:WQ`DB$`"(H'$$#Y(0`&RBE`*8LA,X_2
M05"K\D(``8M"``>+2@$!BRD!`@OL"T#Y(OU;TT(4":I"``J+:@$%RDH!!(J,
M`0&+2@$%RDH!!HM/``H+@OQ"TT)X!*IC``+*ZOU;TV,`"8I*%0^J8P`+RDH!
M#(MC``6+37Q`DDX!`PLC_4+3:7@)JN,/0/G*_5O32A4.JBQ]0))C``&+2@$#
MBT,`"<IC``^*8P`-RF,`"XOB$T#Y40$#"^/]0M,J_EO38W@/JD(``8M*%1&J
M2@$"BR(!`\I"``Z*:WQ`DD(`#,I"``V+2@$""\+]0M-">`ZJ[A=`^6,``LI)
M_5O38P`1BLX!`8LI%0JJ8P`+RBD!#HMC``R+37Q`DC`!`PLC_D+38W@1JD(`
M`\H)_EO30@`*BBD5$*I"``W*;'Q`DD(`"XON+T.IS@$!BVL!`8LI`0Z++P$"
M"T+]0M-">`JJ8P`"RNG]6]-C`!"**14/JF,`#,HI`0N+8P`-BTI\0)(N`0,+
M`_Y"T^TC0/EC>!"J0@`#RLG]6]-"``^*K0$!BRD5#JI"``K*0@`,BRD!#8LM
M`0(+XOU"TT)X#ZIK?$"2[R=`^6,``LJI_5O38P`.BN\!`8LI%0VJ8P`+RBD!
M#XMC``J+3'Q`DB\!`PO#_4+38W@.JNXK0/E"``/*Z?U;TT(`#8K.`0&+*14/
MJD(`#,HI`0Z+0@`+BVI\0)(N`0(+HOU"TT)X#:KM+T#Y8P`"RLG]6]-C``^*
MK0$!BRD5#JIC``K**0$-BV,`#(M+?$"2+0$#"^/]0M-C>`^J[S-`^4(``\JI
M_5O30@`.BN\!`8LI%0VJ0@`+RBD!#XM"``J+;'Q`DB\!`@O"_4+30G@.JNXW
M0/EC``+*Z?U;TV,`#8K.`0&+*14/JF,`#,HI`0Z+8P`+BTI\0)(N`0,+H_U"
MTV-X#:KM.T#Y0@`#RLG]6]-"``^*K0$!BRD5#JI"``K**0$-BT(`#(MK?$"2
M+0$""^+]0M-">`^J[S]`^6,``LJI_5O38P`.BN\!`8LI%0VJ8P`+RBD!#XMC
M``J+3'Q`DB\!`PO#_4+38W@.JNY#0/E"``/*Z?U;TT(`#8K.`0&+*14/JD(`
M#,HI`0Z+0@`+BVI\0)(N`0(+HOU"TT)X#:KM1T#YR?U;TRD5#JI+?$"2K0$!
MBV,``LHI`0V+[?U"TZUY#ZIC``^*0@`-RF,`"LI"``Z*8P`,BT(`"\HI`0,+
M0@`*BZQ]0)+O*TFI(_U;TV,4":KO`0&+00$!B^-!(XMO``(+<``"B\/]0M/B
M_5O38W@.JD(4#ZHB0"*+H0$#RB$`"8HA``S*(0`+BRO]0M-.``&+0@`!"VMY
M":HA=)W2Z5-`^4K\6]-*%0*J(=NM\BD!`8LJ02J+:0`+RBD!$$HI`0R+30$)
M"U`!"8OL5T#YJOU;T^G]0M-*%0VJ*7D/JHP!`8N*02J+;`$)RHP!#DJ#02.+
M3`$#"TX!`XM#_$+38W@"JHK]6]/B6T#Y2A4,JD(``8M*0"J+(@$#RD(`$$I"
M0"N+2P$""U`!`HNB_4+30G@-JFK]6]/M7T#Y2A4+JJT!`8NJ02J+;0`"RJT!
M#DJI02F+3@$)"T\!"8N)_4+3*7D,JLK]6]/L8T#Y2A4.JHP!`8N*02J+3``)
MRHP!$$J#02.+30$#"U`!`XMC_4+38W@+JJK]6]/K9T#Y2A4-JFL!`8MJ02J+
M*P$#RFL!#TIB02*+3`$""T\!`HOK:T#YBOU;T\+]0M-*%0RJ0G@.JFL!`8MJ
M02J+:P`"RFL!$$II02F+2P$)"U`!"8NI_4+3*7D-JFK]6]/M;T#Y2A4+JJT!
M`8NJ02J+30`)RJT!#TJC02.+3@$#"T\!`XN#_4+38W@,JLK]6]/L<T#Y2A4.
MJHP!`8N*02J++`$#RHP!$$J"02*+30$""U`!`HMB_4+30G@+JJK]6]/K=T#Y
M2A4-JFL!`8MJ02J+:P`"RFL!#TII02F+3`$)"T\!"8OK>T#YBOU;T\G]0M-*
M%0RJ*7D.JFL!`8MJ02J+2P`)RFL!$$IC02.+2P$#"U`!`XNC_4+38W@-JFK]
M6]/M?T#Y2A4+JJT!`8NJ02J++0$#RJT!#TJB02*+3@$""T\!`HN"_4+30G@,
MJLK]6]/L@T#Y2A4.JHP!`8N*02J+;``"RHP!$$J)02F+30$)"U`!"8MI_4+3
M*7D+JJK]6]/KAT#Y2A4-JFL!`8MJ02J+2P`)RFL!#TIC02.+3`$#"T\!`XOK
MBT#YBOU;T\/]0M-*%0RJ8W@.JFL!`8MJ02J+*P$#RFL!$$IB02*+2P$""TX!
M`HNB_4+337@-JFK]6]/BCT#Y2A4+JD(``8M*0"J+8@`-RD(`#TI)0"F+@OU"
MTT\!"8M*`0D+3'@,JN*30/E)_5O3*14*JD(``8M)0"F+H@$,RD(`#DI#0".+
M8OU"TRX!`XLI`0,+2W@+JN*70/DC_5O38Q0)JD(``8M#0".+@@$+RD(`#TI"
M0"V+;0`"BV,``@M"_4+33W@*JFK\6]/BFT#Y2A4#JD(``8M*`0*+8@$/RD(`
M#DI"0"R+3@$""R+]0M-">`FJZ9]`^<K]6]-*%0ZJ(0$!BTH!`8OA`0+*(0`-
M2B%`*XOIHT#Y30$!"V'\0M,A>`.JJOU;TX.;E])+``&J8^.Q\DH5#:HI`0.+
M:P$.BDH!"8LI``(*:P$)JFE!+XM,`0D+R?U"TRYY#JKIIT#YBOU;TRL`#JI*
M%0RJ*0$#BVL!#8I*`0F+R0$!"FL!":IB02*+40$""Z+]0M-->`VJXJM`^2K^
M6]/+`0VJ2A41JD(``XMK`0R*2@$"BZ(!#@IK`0*J84$ABU`!`0N!_4+3+'@,
MJN&O0/D*_EO3JP$,JDH5$*HA``.+:P$1BDH!`8N!`0T*:P$!JB'^0M-I02Z+
M3P$)"REX$:KALT#YZOU;TXL!":I*%0^J(0`#BVL!$(I*`0&+(0$,"FL!`:H!
M_D+38D$MBTX!`@LB>!"JX;=`^<K]6],K`0*J2A4.JB$``XMK`0^*2@$!BT$`
M"0IK`0&J84$LB^N[0/E,`0$+X?U"TXK]6],A>`^J:P$#BTH5#*I*`0N+2P`!
MJBT``@IK`0Z*:P$-JFE!*8M-`0D+R?U"TRYY#JKIOT#YJOU;TRL`#JI*%0VJ
M*0$#BVL!#(I*`0F+R0$!"FL!":IB02*+40$""X+]0M-,>`RJXL-`^2K^6]/+
M`0RJ2A41JD(``XMK`0V*2@$"BX(!#@IK`0*J84$ABU`!`0NA_4+3+7@-JN''
M0/D*_EO3BP$-JDH5$*HA``.+:P$1BDH!`8NA`0P*:P$!JB'^0M-I02Z+3P$)
M"REX$:KART#YZOU;TZL!":I*%0^J(0`#BVL!$(I*`0&+(0$-"FL!`:H!_D+3
M8D$LBTP!`@LB>!"JX<]`^8K]6],K`0*J2A4,JB$``XMK`0^*2@$!BT$`"0IK
M`0&J84$MB^O30/E.`0$+X?U"T\K]6],A>`^J:P$#BTH5#JI*`0N+2P`!JBT`
M`@IK`0R*:P$-JFE!*8M-`0D+B?U"TRQY#*KIUT#YJOU;TRL`#*I*%0VJ*0$#
MBVL!#HI*`0F+B0$!"FL!":IB02*+4`$""\+]0M-.>`ZJXMM`^0K^6].+`0ZJ
M2A40JD(``XMK`0V*2@$"B\(!#`IK`0*J84$ABT\!`0NA_4+3+7@-JN'?0/GJ
M_5O3RP$-JDH5#ZHA``.+:P$0BDH!`8NA`0X*:P$!J@'^0M-I02R+3`$)"REX
M$*KAXT#YBOU;TZL!":I*%0RJ(0`#BVL!#XI*`0&+(0$-"FL!`:KA_4+38D$N
MBU`!`@LB>`^JX>=`^0K^6],K`0*J2A40JB$``XMK`0R*2@$!BT$`"0IK`0&J
M84$MBT\!`0N!_4+3+'@,JN'K0/GJ_5O32A4/JDL`#*HA``.+:P$0BBI`*HN!
M`0(*:P$!J@'^0M-I02F+*W@0JDX!"0M1`0F+X>]`^<G]6],I%0ZJ(0`#BR-`
M*8N)`0NJ80$,"BD!#XHI`0&JX?U"TR)!(HLO>`^J;0`""VH``HOA\T#YH_U;
MTV,4#:K".IC20DRY\B$``HLC0".+80$/RB$`$4HA0"R+;``!"W```8O!_4+3
M*7@.JH/]6]/A]T#Y8Q0,JB$``HLC0".+X0$)RB$`"DHA0"N+:P`!"VX``8NA
M_4+3(W@-JFK]6]/A^T#Y2A4+JB$``HLJ0"J+(0$#RB$`$$HA0"^+30$!"T\!
M`8N!_4+3(7@,JJK]6]/L_T#Y2A4-JHP!`HN*02J+;``!RHP!#DJ)02F+3`$)
M"TX!"8MI_4+3*7D+JHK]6]/K`T'Y2A4,JFL!`HMJ02J+*P`)RFL!#TIC02.+
M2P$#"U`!`XNC_4+38W@-JFK]6]/M!T'Y2A4+JJT!`HNJ02J++0$#RJT!#DJA
M02&+3@$!"T\!`8N!_4+3(7@,JLK]6]/L"T'Y2A4.JHP!`HN*02J+;``!RHP!
M$$J)02F+30$)"U`!"8MI_4+3*7D+JJK]6]/K#T'Y2A4-JFL!`HMJ02J+*P`)
MRFL!#TIC02.+3`$#"T\!`XOK$T'YBOU;T\/]0M-*%0RJ8W@.JFL!`HMJ02J+
M*P$#RFL!$$IA02&+2P$!"U`!`8NA_4+3(7@-JFK]6]/M%T'Y2A4+JJT!`HNJ
M02J+;0`!RJT!#TJI02F+3@$)"T\!"8N)_4+3*7D,JLK]6]/L&T'Y2A4.JHP!
M`HN*02J++``)RHP!$$J#02.+30$#"U`!`XMC_4+38W@+JJK]6]/K'T'Y2A4-
MJFL!`HMJ02J+*P$#RFL!#TIA02&+3`$!"T\!`8OK(T'YBOU;T\']0M-*%0RJ
M(7@.JFL!`HMJ02J+:P`!RFL!$$II02F+2P$)"TX!"8NI_4+3*7D-JFK]6]/M
M)T'Y2A4+JJT!`HNJ02J++0`)RJT!#TJC02.+30$#"T\!`XN#_4+38W@,JJK]
M6]/L*T'Y2A4-JHP!`HN*02J++`$#RHP!#DJ!02&+3`$!"TX!`8MA_4+3(7@+
MJHK]6]/K+T'Y2A4,JFL!`HMJ02J+:P`!RFL!#TII02F+2P$)"T\!"8NI_4+3
M*GD-JFG]6]/M,T'Y*14+JJT!`HNI02F++0`*RJT!#DJC02.++@$#BR,!`POM
M-T'YB?U"TRQY#*II_%O3*14#JJT!`HN$0"R+J4$IBTT!#,JM`0]*H4$ABRT!
M`0LO`0&+Z3M!^6']0M,K>`NJH?U;TRD!`HLA%`VJ(0`)BXD!"\HI`0Y**D$J
MBVG\0M,A``H+(WD#JNH_0?EI`0/**0$/2F,`!@M"`0*+*OQ;TTH5`:HB`0*+
M(0`("T0!!(M"``0+`@0`J:']0M,A>`VJ(0`%"P$,`:EA`0<+`1``^<```/``
MU$?YXD=!^0$`0/E"``'K`0"`TJ$``%3_0PJ1_7O!J+\C`]7``U_6WO+_EQ\@
M`]4_(P/5_7N_J0`0@-+]`P"1Y/+_ER(``+`?&`#Y'W@`N5]TP#TB``"P7GC`
M/2(``+`?>`"M7WS`/1\(@#W]>\&HOR,#U<`#7]8_(P/5_7N[J?T#`)'S4P&I
M]`,`JD!\0)/U6P*I]@,`JI7B`)'W8P.I^`,!JH2*0JF##``+GP`#ZT*4@II`
M=$"+@X("J8!Z0+G`!``UW_X`<2T#`%37?@93^2,`^?D&`%'S`QBJ]V8:4Q<#
M%XL?(`/5'R`#U1\@`]5]<D"MX`,4JG]Z0:US`@&1O7(`K;]Z`:V*^_^7?P(7
MZP'__U08`P&1``B`4M8"`5'6&AE+.&.@F_DC0/G"?D"3X0,8JN`#%:H^\O^7
MEGH`N?-30:GU6T*I]V-#J?U[Q:B_(P/5P`-?UA,(@%)S`@!+?P(6:Z#"((MS
MTI8:8GY`DS#R_Y>`>D"Y8`(`"X!Z`+D?``%QX?W_5-8"$TL8PS.+X`,4JF?[
M_Y?+__\7/R,#U?U[O*DCX`"1X@^`$OT#`)'S4P&I]`,`JO,#`:KU6P*I-=A"
MJ:`B`U,!!``18L@@.&#`(8L_X`!QS0L`5`((@%)"``%+`0"`4N,?`/E"?$"3
MQ/+_E^`#$ZI.^_^7'P0`3^,?0/E_@H,\?Q@`^7_\`*W?`F>>P'X84_H'<'_[
M!WA_OP)GGOP':'_]!W!__@=X?Q\`9Y[@`Q.J7P<#;G\'!6[?'@=.GP<);K\'
M"V[?!PUNOQX/3G\Z`/TV^_^78`)`^0#\6-.``@`Y8`)`^0#\4-.`!@`Y8`)`
M^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y`/Q8TX`2`#E@!D#Y`/Q0TX`6`#E@!D#Y
M`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`_%C3@"(`.6`*0/D`_%#3@"8`.6`*0/D`
M_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\6-.`,@`Y8`Y`^0#\4-.`-@`Y8`Y`^0#\
M2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8TX!"`#E@$D#Y`/Q0TX!&`#E@$D#Y`/Q(
MTX!*`#E@$D#Y@$X`.>`#$ZKU6T*I\U-!J?U[Q*B_(P/54?+_%P('@%)"``%+
M`0"`4D)\0)-H\O^7J___%Q\@`]4?(`/5PP``\&,$0/GZ\?\7'R`#U?U[OZG]
M`P"1_7O!J,`#7]8!``(``````"5S+R5S````+W!R;V,O<V5L9B]E>&4``$1Y
M;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@``````26YT97)N86QS.CI005(Z
M.D)/3U0`````97AE```````O<')O8R\E:2\E<P``````+@````````!005)?
M5$5-4```````````4$%27U!23T=.04U%`````#H`````````+P`````````E
M<R5S)7,``%!%4DPU3$E"``````````!015),3$E"`%!%4DPU3U!4````````
M``!015),24\``%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1```````4$%2
M7T-,14%.`````````%!!4E]$14)51P````````!005)?0T%#2$4`````````
M4$%27T=,3T)!3%]$14)51P``````````4$%27T=,3T)!3%]435!$25(`````
M````4$%27U1-4$1)4@```````%!!4E]'3$]"04Q?5$5-4`!005)?1TQ/0D%,
M7T-,14%.```````````Q`````````&QS965K(&9A:6QE9`````!R96%D(&9A
M:6QE9```````3$1?3$E"4D%265]0051(`%-94U1%30``)3`R>`````!P87(M
M`````"5S)7,E<R5S```````````E<SH@8W)E871I;VX@;V8@<')I=F%T92!S
M=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE:2D*````````)7,Z('!R
M:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE87-E(')E;6]V
M92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@```````%!!5$@`````
M<&%R;``````N<&%R`````'-H;W)T(')E860````````E<R5S8V%C:&4M)7,E
M<P``)7,E<W1E;7`M)74E<P```"5S)7-T96UP+25U+25U)7,``````````!@`
M````````<&5R;``````P`````````%!!4CHZ4&%C:V5R.CI615)324].````
M`#$N,#8S````56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`````
M`````"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H``````````"UE````````+2T`````
M``!54T52`````%5315).04U%``````````!435!$25(``%1%35!$25(`5$5-
M4`````!435```````"]T;7``````979A;"`G97AE8R`O=7-R+V)I;B]P97)L
M("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI;F<@=6YD97(@
M<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)%!!4E]-04=)0RP@
M)$9)3$5?;V9F<V5T7W-I>F4L("1C86-H95]N86UE7W-I>F4I.PI"14=)3B![
M"B1005)?34%'24,@/2`B7&Y005(N<&U<;B(["B1&24Q%7V]F9G-E=%]S:7IE
M(#T@-#L@("`C('!A8VLH(DXB*0HD8V%C:&5?;F%M95]S:7IE(#T@-#`["B10
M2UI)4%]-04=)0R`](")02UPP,#-<,#`T(CL*?0IS=6(@9FEN9%]P87)?;6%G
M:6,*>PIM>2`H)&9H*2`]($!?.PIM>2`D8VAU;FM?<VEZ92`](#8T("H@,3`R
M-#L*;7D@)&)U9CL*;7D@)'-I>F4@/2`M<R`D9F@["FUY("1P;W,@/2`H)'-I
M>F4M,2D@+2`H)'-I>F4M,2D@)2`D8VAU;FM?<VEZ93L@("`@("`C($Y/5$4Z
M("1P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H)'!O
M<R`^/2`P*2!["G-E96L@)&9H+"`D<&]S+"`P.PIR96%D("1F:"P@)&)U9BP@
M)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)0RD["FEF("@H;7D@)&D@
M/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X](#`I('L*<F5T=7)N("1P
M;W,@*R`D:3L*?0HD<&]S("T]("1C:'5N:U]S:7IE.PI]"G)E='5R;B`M,3L*
M?0IM>2`H)'!A<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE+"`E36]D=6QE
M0V%C:&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["G)E<75I<F4@
M1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*<F5Q=6ER92!&
M:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'!A<E]T96UP*3L*;W5T<RAQ<5M296UO=FEN9R!F:6QE<R!I;B`B)'!A
M<E]T96UP(ETI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H<W5B('L@*"`M9"`I
M(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*<FUD:7(@)'!A<E]T
M96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G35-7:6XS,B<I('L*
M;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%412`]/B`G=&UP6%A8
M6%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H)'1O<&1I<BDL
M"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI.PIM>2`D9FEL96YA
M;64@/2`D=&UP+3YF:6QE;F%M93L*<')I;G0@)'1M<"`\/"(N+BXB.PIX/3$[
M('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*
M:68@6R!<(2`M9"`G)'!A<E]T96UP)R!=.R!T:&5N"F)R96%K"F9I"G-L965P
M(#$*>#U@97AP<B!<)'@@*R`Q8`ID;VYE"G)M("<D9FEL96YA;64G"BXN+@IC
M;&]S92`D=&UP.PIC:&UO9"`P-S`P+"`D9FEL96YA;64["FUY("1C;60@/2`B
M)&9I;&5N86UE(#XO9&5V+VYU;&P@,CXF,2`F(CL*<WES=&5M*"1C;60I.PIO
M=71S*'%Q6U-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O<FT@
M8VQE86YU<#H@)&9I;&5N86UE72D["GT*?2!]"D)%1TE.('L*26YT97)N86QS
M.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!4CHZ0D]/
M5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@)'%U:65T(#T@(21%3E9[
M4$%27T1%0E5'?3L*;7D@)7-Y<R`]("@*<&%T:%]S97`@("`@/3X@*"1>3R`]
M?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E>&4@("`@("`@(#T^("@D7D\@
M/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@/R`G+F5X92<@.B`G)RDL"E]D
M96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O
M)RDL"BD["E]S971?<')O9VYA;64H*3L*;W5T<RAQ<5M<)'!R;V=N86UE(#T@
M(B1P<F]G;F%M92)=*3L*7W-E=%]P87)?=&5M<"@I.PIO=71S*'%Q6UPD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2)=*3L*;7D@*"1S=&%R=%]P
M;W,L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI.PI-04=)0SH@>PIL;V-A;"`D
M4TE'>U]?5T%23E]??2`]('-U8B![?3L*=6YL97-S("AO<&5N(%]&2"P@)SPZ
M<F%W)RP@)'!R;V=N86UE*2!["F]U=',H<7%;0V%N)W0@<F5A9"!F<F]M(&9I
M;&4@(B1P<F]G;F%M92)=*3L@(",@9&]N)W0@=7-E("0A(&AE<F4@87,@:70@
M<F5Q=6ER97,@17)R;F\N<&T*;&%S="!-04=)0SL*?0IM>2`D;6%G:6-?<&]S
M(#T@9FEN9%]P87)?;6%G:6,H*E]&2"D["FEF("@D;6%G:6-?<&]S(#P@,"D@
M>PIO=71S*'%Q6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#
M(B!I;B!F:6QE("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*;W5T<R@B
M1F]U;F0@4$%2(&UA9VEC(&%T('!O<VET:6]N("1M86=I8U]P;W,B*3L*<V5E
M:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92`M(&QE;F=T
M:"@B7#!#04-(12(I+"`P.PIR96%D(%]&2"P@)&)U9BP@;&5N9W1H*")<,$-!
M0TA%(BD["FEF("@D8G5F(&YE(")<,$-!0TA%(B`F)B`D8G5F(&YE(")<,$-,
M14%.(BD@>PIO=71S*").;R!C86-H92!M87)K97(@9F]U;F0B*3L*;&%S="!-
M04=)0SL*?0IO=71S*'%Q6T-A8VAE(&UA<FME<B`B)&)U9B(@9F]U;F1=*3L*
M<V5E:R!?1D@L("1M86=I8U]P;W,@+2`D1DE,15]O9F9S971?<VEZ92P@,#L*
M<F5A9"!?1D@L("1B=68L("1&24Q%7V]F9G-E=%]S:7IE.PIM>2`D;V9F<V5T
M(#T@=6YP86-K*").(BP@)&)U9BD["F]U=',H(D]F9G-E="!F<F]M('-T87)T
M(&]F($9)3$5S(&ES("1O9F9S970B*3L*<V5E:R!?1D@L("1M86=I8U]P;W,@
M+2`D1DE,15]O9F9S971?<VEZ92`M("1O9F9S970L(#`["B1S=&%R=%]O9E]&
M24Q%7W-E8W1I;VX@/2!T96QL(%]&2#L*;7D@)7)E<75I<F5?;&ES=#L*<F5A
M9"!?1D@L("1B=68L(#0[("`@("`@("`@("`@("`@("`@("`@("`@("`@(R!R
M96%D('1H92!F:7)S="`B1DE,12(*=VAI;&4@*"1B=68@97$@(D9)3$4B*2![
M"G)E860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").
M(BP@)&)U9BD["FUY("1F=6QL;F%M92`]("1B=68["F]U=',H<7%;56YP86-K
M:6YG($9)3$4@(B1F=6QL;F%M92(N+BY=*3L*;7D@)&-R8R`]("@@)&9U;&QN
M86UE(#U^('-\7BA;82UF7&1=>SA]*2]\?"`I(#\@)#$@.B!U;F1E9CL*;7D@
M*"1B87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<
M+BXJ*7PI.PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N
M<&%C:R@B3B(L("1B=68I.PII9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A
M?B`O7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1C<F,D97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&9U;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<V4@>PHD
M36]D=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]
M/B`D8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD
M9G5L;&YA;65]*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.
M0R`]("AS=6(@>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I
M9B!R968@)&UO9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE
M0V%C:&5[)&UO9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D
M<F5Q=6ER95]L:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D
M97(O)&EN9F\O)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E
M9FEN960H)DE/.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A
M(CL*)&9H+3YB:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*
M)&9H+3YS965K*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL
M96YA;64@/2!?<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB
M=69]*3L*)&EN9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L
M("<\.G)A=R<L("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I
M;&5N86UE(CH@)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN
M9R!F86EL960Z(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.
M0RD["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q
M=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL
M93L*=VAI;&4@*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?
M;&ES="E;,%TI('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N
M86UE(#U^("]"4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O
M:2D@>PIR97%U:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE
M('5N;&5S<R`D9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*
M?0ID96QE=&4@)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F
M(&YE("102UI)4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E
M<B!&24Q%('-E8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!
M1TE#(#L*?0HD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@
M("`@("`@(",@<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U
M="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=
M(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD
M(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N
M:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF
M("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!
M4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS
M92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW
M:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4
M=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?
M=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D
M,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@
M)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@
M*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E
M<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I
M('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO
M9V9H+"`B/CXB+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B
M)#(B.B`D(5T["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]
M("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[
M)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR
M97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE
M<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8[
M"F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@
M*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z
M.EII<#L*<F5Q=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H
M0$%21U8I.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F
M:6QE("(D<&%R(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP
M(#T@07)C:&EV93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N
M9&QE*"1F:"P@)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@
M9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM
M>2`E;65T85]P87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z
M:7`M/F-O;G1E;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R
M.B0O+VUS.PHD;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;
M7CI=*RDZ("@N*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E
M;B!M>2`D<&@L("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@
M<&%R(&9I;&4@(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F
M+"`T.PID:64@<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@
M)&)U9B!E<2`D4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H
M*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I
M;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE
M.CI/7U1254Y#*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F
M:6QE("(D;W5T(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L
M(#`["FUY("1L;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VXI('L*<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E
M8W1I;VX["GT@96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\
M7T9(/CL*?0II9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]
M?B`O7B@_.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D
M4W1R:7`["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L
M("0P*3L*?0HD9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W
M<FET:6YG(&QO861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*
M<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A
M9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC
M(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET
M92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD
M"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*
M<WPO*WPO?&<L('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I
M;&5S>R1??2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L
M('9A;'5E<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML
M:6)?97AT?3L@("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@
M)7=R:71T96X["F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@
M>PIM>2`H)&9I;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!
M4CHZ2&5A=GDZ.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC
M*2!["FEF("@D:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE
M+"`D;F%M92D@/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\
M7B]L;V%D97(O6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L
M94-A8VAE>R0Q?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA
M<W0["GT*:68@*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B
M)&1I<B\D,2(L("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I
M;F5D("1N86UE.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF
M("%R968H)&9I;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD[
M"F]U=',H<W!R:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*
M:68@*')E9B@D9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*
M96QS92!["FQO8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G
M+"`D9FEL92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C
M;VYT96YT(#T@/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YA<'!L>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@
M(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\
M86PI)"]I.PI005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY
M*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%
M(BP*<&%C:R@G3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64I+`IP86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT
M*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D
M;W5T(CH@)"%=.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*
M:68@*"1Z:7`I('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II
M<"!P87)T(&]F("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*
M)&9H+3YP<FEN="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@
M)&-A8VAE7VYA;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D[
M"G-E96L@)&9H+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H
M+"`P+"`R.PHD8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C
M:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?
M<VEZ93L*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE
M("T@;&5N9W1H("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M
M92P*(EPP0T%#2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N
M9W1H*"1L;V%D97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*
M)%!!4E]-04=)0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I
M;F<@=')A:6QE<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*
M97AI=#L*?0I["FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I
M>%]P<F]G;F%M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?
M9'EN86QO861E<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!
M<F-H:79E.CI::7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@
M("`@("`@("`@("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S
M(&]N(&%N($E/.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R
M)RD@;W(@9&EE('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI:
M:7`Z.G-E=$-H=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ
M6FEP+3YN97<["B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O
M9VYA;64I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E
M.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI
M8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II
M<#L*;W5T<R@B17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.
M5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A
M"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@
M:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M
M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@
M;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_
M"BA;7B]=*RD*)`I]>#L*;7D@)&5X=')A8W1?;F%M92`]("0Q.PIM>2`D9&5S
M=%]N86UE(#T@1FEL93HZ4W!E8RT^8V%T9FEL92@D14Y6>U!!4E]414U0?2P@
M)&5X=')A8W1?;F%M92D["FEF("@M9B`D9&5S=%]N86UE("8F("US(%\@/3T@
M)&UE;6)E<BT^=6YC;VUP<F5S<V5D4VEZ92@I*2!["F]U=',H<7%;4VMI<'!I
M;F<@(B1M96UB97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@
M(B1D97-T7VYA;64B72D["GT@96QS92!["F]U=',H<7%;17AT<F%C=&EN9R`B
M)&UE;6)E<E]N86UE(B!T;R`B)&1E<W1?;F%M92(N+BY=*3L**"1M96UB97(M
M/F5X=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!E>'1R86-T:6YG('II<"!M
M96UB97(@=&\@(B1D97-T7VYA;64B73L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M
M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI
M8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8[
M"E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE
M(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM
M3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"![
M"FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@[
M"D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@
M(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE
M<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@
M:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E
M<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y
M.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q
M=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI4
M96UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E
M<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z
M.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV
M93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!4CL*<F5Q
M=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q=6ER92!0
M05(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!A
M=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@<F5Q=6ER
M92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![(')E<75I
M<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N
M>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z.DYA;65D
M0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I<F4@4&5R
M;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]"G-U8B!?
M<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-4'T@86YD
M("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@/2`D,3L*
M<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[)%]]+"!Q
M=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I*2P*<7<H
M($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I;F5D("1P
M871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R;F%M93L*
M;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D
M969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M92D@
M*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L<VEF("AD
M969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*96QS92![
M"B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%4GT@?'P@
M)U-94U1%32<["GT*;7D@)'-T;7!D:7(@/2`B)'!A=&@D<WES>U]D96QI;7UP
M87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@)'-T;7!D:7(L
M(#`W-34["FUY("1C86-H95]D:7(["FEF("@D14Y6>U!!4E]#3$5!3GTI('L*
M)&-A8VAE7V1I<B`](")T96UP+20D(CL*?0IE;'-E('L*;W!E;B!M>2`D9F@L
M("(\.G)A=R(L("1P<F]G;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)'!R
M;V=N86UE(CH@)"%=.PII9B`H*&UY("1M86=I8U]P;W,@/2!F:6YD7W!A<E]M
M86=I8R@D9F@I*2`^/2`P*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)
M3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*;7D@)&)U
M9CL*<F5A9"`D9F@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U
M9B!E<2`B7#!#04-(12(I('L*<V5E:R`D9F@L("1M86=I8U]P;W,*+2`D1DE,
M15]O9F9S971?<VEZ90HM(&QE;F=T:"@B7#!#04-(12(I"BT@)&-A8VAE7VYA
M;65?<VEZ92P@,#L*<F5A9"`D9F@L("1B=68L("1C86-H95]N86UE7W-I>F4[
M"B1B=68@/7X@<R]<,"\O9SL*)&-A8VAE7V1I<B`](")C86-H92TD8G5F(CL*
M?0I]"F-L;W-E("1F:#L*?0II9B`H(21C86-H95]D:7(I('L*)&-A8VAE7V1I
M<B`](")T96UP+20D(CL*)$5.5GM005)?0TQ%04Y](#T@,3L*?0HD<W1M<&1I
M<B`N/2`B)'-Y<WM?9&5L:6U])&-A8VAE7V1I<B(["FUK9&ER("1S=&UP9&ER
M+"`P-S4U.PHD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIL87-T.PI]"B1P
M87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\["GT*<W5B(%]S879E7V%S('L*;7D@*"1N86UE+"`D
M8V]N=&5N=',L("1M;V1E*2`]($!?.PIM>2`D9G5L;&YA;64@/2`B)'!A<E]T
M96UP+R1N86UE(CL*=6YL97-S("@M92`D9G5L;&YA;64I('L*;7D@)'1E;7!N
M86UE(#T@(B1F=6QL;F%M92XD)"(["FUY("1F:#L**&]P96X@)&9H+"`G/CIR
M87<G+"`D=&5M<&YA;64I"B8F("AP<FEN="`D9F@@)&-O;G1E;G1S*0HF)B`H
M8VQO<V4@)&9H*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R`B)'1E;7!N86UE
M(CH@)"%=.PIC:&UO9"`D;6]D92P@)'1E;7!N86UE(&EF(&1E9FEN960@)&UO
M9&4["G)E;F%M92@D=&5M<&YA;64L("1F=6QL;F%M92D@;W(@=6YL:6YK*"1T
M96UP;F%M92D["GT*<F5T=7)N("1F=6QL;F%M93L*?0IS=6(@7W-E=%]P<F]G
M;F%M92!["FEF("AD969I;F5D("1%3E9[4$%27U!23T=.04U%?2!A;F0@)$5.
M5GM005)?4%)/1TY!345](#U^("\H+BLI+RD@>PHD<')O9VYA;64@/2`D,3L*
M?0HD<')O9VYA;64@?'P]("0P.PII9B`H)$5.5GM005)?5$5-4'T@86YD(&EN
M9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*)'!R;V=N
M86UE(#T@<W5B<W1R*"1P<F]G;F%M92P@<FEN9&5X*"1P<F]G;F%M92P@)'-Y
M<WM?9&5L:6U]*2`K(#$I.PI]"FEF("@A)$5.5GM005)?4%)/1TY!345](&]R
M(&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L:6U]*2`^/2`P*2!["FEF("AO
M<&5N(&UY("1F:"P@)SPG+"`D<')O9VYA;64I('L*<F5T=7)N(&EF("US("1F
M:#L*?0II9B`H+7,@(B1P<F]G;F%M921S>7-[7V5X97TB*2!["B1P<F]G;F%M
M92`N/2`D<WES>U]E>&5].PIR971U<FX["GT*?0IF;W)E86-H(&UY("1D:7(@
M*'-P;&ET("]<421S>7-[<&%T:%]S97!]7$4O+"`D14Y6>U!!5$A]*2!["FYE
M>'0@:68@97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[
M4$%27U1%35!].PHD9&ER(#U^(',O7%$D<WES>U]D96QI;7U<120O+SL**"@D
M<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X
M97TB*2P@;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D
M<WES>U]E>&5](CL**"@D<')O9VYA;64@/2`B)&1I<B1S>7-[7V1E;&EM?21P
M<F]G;F%M92(I+"!L87-T*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G
M;F%M92(["GT*?0IS=6(@7V9I>%]P<F]G;F%M92!["B0P(#T@)'!R;V=N86UE
M('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["FEF("AI;F1E>"@D<')O9VYA;64L
M("1S>7-[7V1E;&EM?2D@/"`P*2!["B1P<F]G;F%M92`]("(N)'-Y<WM?9&5L
M:6U])'!R;V=N86UE(CL*?0IM>2`D<'=D(#T@*&1E9FEN960@)D-W9#HZ9V5T
M8W=D*2`_($-W9#HZ9V5T8W=D*"D*.B`H*&1E9FEN960@)E=I;C,R.CI'971#
M=V0I(#\@5VEN,S(Z.D=E=$-W9"@I(#H@8'!W9&`I.PIC:&]M<"@D<'=D*3L*
M)'!R;V=N86UE(#U^(',O7B@_/5PN7"X_7%$D<WES>U]D96QI;7U<12DO)'!W
M9"1S>7-[7V1E;&EM?2\["B1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M
M93L*?0IS=6(@7W!A<E]I;FET7V5N=B!["FEF("@@)$5.5GM005)?24Y)5$E!
M3$E:141]*RL@/3T@,2`I('L*<F5T=7)N.PI](&5L<V4@>PHD14Y6>U!!4E])
M3DE424%,25I%1'T@/2`R.PI]"F9O<B`H<7<H(%-005=.140@5$5-4"!#3$5!
M3B!$14)51R!#04-(12!04D]'3D%-12`I("D@>PID96QE=&4@)$5.5GLB4$%2
M7R1?(GT["GT*9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@
M>PHD14Y6>R)005)?)%\B?2`]("1%3E9[(E!!4E]'3$]"04Q?)%\B?2!I9B!E
M>&ES=',@)$5.5GLB4$%27T=,3T)!3%\D7R)].PI]"FEF("@D14Y6>U!!4E]4
M14U0?2D@>PID96QE=&4@)$5.5GM005)?0TQ%04Y].PI]"GT*<W5B(&]U=',@
M>PIR971U<FX@:68@)'%U:65T.PII9B`H)&QO9V9H*2!["G!R:6YT("1L;V=F
M:"`B0%]<;B(["GT*96QS92!["G!R:6YT(")`7UQN(CL*?0I]"G-U8B!I;FET
M7VEN8R!["G)E<75I<F4@0V]N9FEG.PIP=7-H($!)3D,L(&=R97`@9&5F:6YE
M9"P@;6%P("1#;VYF:6<Z.D-O;F9I9WLD7WTL('%W*`IA<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`IV96YD;W)A<F-H97AP
M('9E;F1O<FQI8F5X<`HI.PI]"G!A8VMA9V4@;6%I;CL*<F5Q=6ER92!005([
M"G5N<VAI9G0@0$E.0RP@7"9005(Z.F9I;F1?<&%R.PI005(M/FEM<&]R="A`
M<&%R7V%R9W,I.PID:64@<7%;<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R
M:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&Y=
M"G5N;&5S<R`M92`D<')O9VYA;64["F1O("1P<F]G;F%M93L*0T]213HZ97AI
M="@D,2D@:68@*"1`(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("1`
M(&EF("1`.PI].PHD.CI?7T524D]2(#T@)$`@:68@)$`["GT*0T]213HZ97AI
M="@D,2D@:68@*"0Z.E]?15)23U(@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)#HZ7U]%4E)/4B!I9B`D.CI?7T524D]2.PHQ.PI?7T5.1%]?"@!P
M97)L>'-I+F,``````````$-!0TA%```!(T5G`````(FKS>\`````_MRZF```
M``!V5#(0`````/#ATL,````````````````!&P,[#`$``"``````B/__G`8`
M`$"*__\D`0``H(K__S@!``#0BO__3`$```R+__]@`0``8(O__X@!``"`B___
MH`$``(",__\,`@``)(W__S@"``"LCO__D`(``."0___,`@``Y)'__P`#``!@
MDO__*`,``)"2__\\`P``@)/__W`#``"(D___A`,``,R5___H`P```);__Q`$
M``"$E___<`0``*"<__^P!```()W__]@$``#`G?__]`0``!"?__\X!0``0)__
M_UP%``!@H/__H`4``,"F__\L!@``Y*C__V0&````JO__T`8```"[__\`!P``
M2+O__R0'``!LO/__9`<``$"^__^8!P```````!```````````7I2``1X'@$;
M#!\`$````!@````4B?__-`````!!!QX0````+````&")__\P`````````!``
M``!`````?(G__SP`````````)````%0```"DB?__4`````!!+4$.()T$G@-"
MDP).WMW3#@!!+0```!0```!\````T(G__P@``````````````&@```"4````
MV(G___@`````02U!#D"=")X'0I<"F`%%DP:4!4*6`Y4$6-;51-[=U]C3U`X`
M02U!#D"3!I0%E026`Y<"F`&=")X'+4[6U4/>W=?8T]0.`$$M00Y`DP:4!9<"
MF`&=")X'+0```"@``````0``;(K__Z0`````02U!#K`!0YT$G@-"DP)7"M/=
MW@X`02U!"P``5````"P!``#DBO__B`$```!!+4$.T`%#G0:>!4:4`Y,$1-33
M2=W>#@!!+4$.T`&3!)0#G0:>!2U!E@&5`GD*U--!UM5!"TG3U-76090#DP1!
ME@&5`@```#@```"$`0``%(S__S0"````02U!#F!!G0B>!T*3!I0%194$E@.7
M`I@!`D<*U]C5UM/4W=X.`$$M00L``#````#``0``#([__P0!````02U!#C"=
M!IX%10[0(),$E`.5`F4*#C!#WMW5T]0.`$$M00LD````]`$``-R.__]P````
M`$$M00X@G02>`T63`I0!3=[=T]0.`$$M$````!P"```PC___,``````````P
M````,`(``$R/___P`````$$M00XPG0:>!40.X$"3!)0#;PH.,$/>W=/4#@!!
M+4$+094"$````&0"```(D/__"`````````!@````>`(``/R/__]$`@```$$M
M00Y0G0J>"44.X"&3")0'E0:6!5\*#E!#WMW5UM/4#@!!+4$+2)@#0YD"0Y<$
M09H!=`K70=A!V4':00M6UT'80=E!VD*7!$&8`T&9`D&:`0``)````-P"``#<
MD?__-`````!!+4$.()T$G@-#DP)&WMW3#@!!+0```%P````$`P``Z)'__X0!
M````02U!#B"=!)X#0P[`($B3`D&4`6D*TT+400X@0=[=#@!!+4$+0=-!U$L.
M($'>W0X`02U!#L`@DP*4`9T$G@,M3`K30M1""T'3U$&3`D&4`3P```!D`P``
M#)/__Q`%````02U!#F!#G0J>"4*3")0'194&E@67!)@#F0(#+`$*V=?8U=;3
MU-W>#@!!+4$+```D````I`,``.B7__^``````$$M00X@0YT"G@%6"MW>#@!!
M+4$+````&````,P#``!`F/__H`````!!+4$.P`)!G1J>&4````#H`P``Q)C_
M_U`!````02U!#C"=!IX%1`ZP@`23!)0#E0*6`4(.P(`$>@H.L(`$00XP0][=
MU=;3U`X`02U!"P``(````"P$``#0F?__*`````!!+4$.$)T"G@%&WMT.`$$M
M````0````%`$``#<F?__'`$```!!+4$.4$&=!IX%0I4"E@%$DP24`UD*U=;3
MU-W>#@!!+4$+8`K5UM/4W=X.`$$M00L```"(````E`0``+B:__]@!@```$$M
M00Z@`T&=#)X+0I<&F`5$DPJ4"4*5")8'79H#F01!G`&;`@)]"MK90=S;1-?8
MU=;3U-W>#@!!+4$+`HW9VMO<3M?8U=;3U-W>#@!!+4$.H`.3"I0)E0B6!Y<&
MF`69!)H#FP*<`9T,G@LM`DO9VMO<09H#F01!G`&;`C0````@!0``C*#__R0"
M````02U!#E!#G0B>!T*3!I0%194$E@.7`@)>"M?5UM/4W=X.`$$M00L`-```
M`%@%``!XHO__!`$```!!+4$.,$&=!)X#0I,"E`%="M/4W=X.`$$M00M:"M/4
MW=X.`$$M00LP````D`4``%R!__\0`@```$$M00Y@09T&G@5(DP24`Y4"E@$"
M5PK5UM/4W=X.`$$M00L`+````,0%```HH____!````!#+4$.$)T"G@%%#J`%
M`S($"@X00=[=#@!!+4$+````(````/0%``#XL___2`````!!+4$.$)T"G@%.
MWMT.`$$M````/````!@&```<M/__)`$```!!+4$.4)T*G@E"DPB4!T.5!I8%
M0Y<$F`--F0)6V4D*WMW7V-76T]0.`$$M00L``#````!8!@```+7__\P!````
M02U!#D"=")X'1),&E`5#E026`P)B"M[=U=;3U`X`02U!"P`0````C`8``*"V
M__\,```````````````$````$`````$```!'3E4```````,````'````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````&`=````````#!T`
M```````!`````````!`#`````````0`````````@`P````````$`````````
M*@,````````,`````````/@5````````#0````````!,4````````!D`````
M````@/L!```````;``````````@`````````&@````````"(^P$``````!P`
M````````"`````````#U_O]O`````+`"````````!0````````"H"0``````
M``8`````````T`(````````*`````````&$#````````"P`````````8````
M`````!4````````````````````#`````````*#]`0```````@````````"(
M!0```````!0`````````!P`````````7`````````'`0````````!P``````
M````#@````````@`````````<`(````````)`````````!@`````````'@``
M```````(`````````/O__V\``````0``"`````#^__]O`````*`-````````
M____;P`````"`````````/#__V\`````"@T```````#Y__]O``````X`````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M```````````````````````0%@```````!`6````````$!8````````0%@``
M`````!`6````````$!8````````0%@```````!`6````````$!8````````0
M%@```````!`6````````$!8````````0%@```````!`6````````$!8`````
M```0%@```````!`6````````$!8````````0%@```````!`6````````$!8`
M```````0%@```````!`6````````$!8````````0%@```````!`6````````
M$!8````````0%@```````!`6````````$!8````````0%@```````!`6````
M````$!8````````0%@```````!`6````````$!8````````0%@```````!`6
M````````$!8````````0%@```````!`6````````$!8````````0%@``````
M`!`6````````$!8````````0%@```````!`6````````$!8````````0%@``
M`````!`6````````$!8````````0%@```````!`6````````$!8````````0
M%@```````!`6````````$!8````````0%@```````!`6````````D/L!````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````&@``````````````````"``"```````*4$%2+G!M"@``````
M````0%0```````#04```````````````````P%$````````@5````````"A4
M````````,%0````````X5```````````````````"%0````````05```````
M````````````2%0```````!'0T,Z("A-86=E:6$@,34N,2XP+3$N;6=A,3`I
M(#$U+C$N,```+G-H<W1R=&%B`"YN;W1E+F=N=2YB=6EL9"UI9``N:6YT97)P
M`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N
M=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E>'0`+F9I
M;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N;F]T92Y!0DDM
M=&%G`"YI;FET7V%R<F%Y`"YF:6YI7V%R<F%Y`"YD>6YA;6EC`"YG;W0`+F1A
M=&$`+F)S<P`N8V]M;65N=```````````````````````````````````````
M```````````````````````````````````````````````````+````!P``
M``(`````````<`(```````!P`@```````"0````````````````````$````
M````````````````'@````$````"`````````)0"````````E`(````````;
M`````````````````````0```````````````````"8```#V__]O`@``````
M``"P`@```````+`"````````'``````````$``````````@`````````````
M```````P````"P````(`````````T`(```````#0`@```````-@&````````
M!0````,````(`````````!@`````````.`````,````"`````````*@)````
M````J`D```````!A`P```````````````````0```````````````````$``
M``#___]O`@`````````*#0````````H-````````D@`````````$````````
M``(``````````@````````!-````_O__;P(`````````H`T```````"@#0``
M`````&``````````!0````(````(````````````````````7`````0````"
M```````````.``````````X```````!P`@````````0`````````"```````
M```8`````````&8````$````0@````````!P$````````'`0````````B`4`
M```````$````%0````@`````````&`````````!P`````0````8`````````
M^!4```````#X%0```````!@````````````````````$````````````````
M````:P````$````&`````````!`6````````$!8```````#0`P``````````
M````````$````````````````````'8````!````!@``````````&@``````
M```:````````3#8``````````````````$````````````````````!\````
M`0````8`````````3%````````!,4````````!0````````````````````$
M````````````````````@@````$````"`````````&!0````````8%``````
M``"@00``````````````````$````````````````````(H````!`````@``
M````````D@````````"2````````#`$```````````````````0`````````
M``````````"8`````0````(`````````$),````````0DP```````*`&````
M```````````````(````````````````````H@````<````"`````````+"9
M````````L)D````````@````````````````````!```````````````````
M`+`````.`````P````````"`^P$``````(#[````````"```````````````
M``````@`````````"`````````"\````#P````,`````````B/L!``````"(
M^P````````@````````````````````(``````````@`````````R`````8`
M```#`````````)#[`0``````D/L````````0`@````````4`````````"```
M```````0`````````-$````!`````P````````"@_0$``````*#]````````
M8`(```````````````````@`````````"`````````#6`````0````,`````
M```````"``````````$``````(@````````````````````(````````````
M````````W`````@````#`````````(@``@``````B``!```````H````````
M````````````"````````````````````.$````!````,```````````````
M`````(@``0``````)`````````````````````$``````````0`````````!
M`````P````````````````````````"L``$``````.H`````````````````
2```!````````````````````
